==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/FinancialChartCustomIndicatorArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { FinancialChartCustomIndicatorArgsDescription } from "./FinancialChartCustomIndicatorArgsDescription";
/**
 * @hidden
 */
var FinancialChartCustomIndicatorArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FinancialChartCustomIndicatorArgsDescriptionMetadata, _super);
    function FinancialChartCustomIndicatorArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FinancialChartCustomIndicatorArgsDescriptionMetadata.b = function (a) {
        if (FinancialChartCustomIndicatorArgsDescriptionMetadata.a == null) {
            FinancialChartCustomIndicatorArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FinancialChartCustomIndicatorArgsDescriptionMetadata.c(FinancialChartCustomIndicatorArgsDescriptionMetadata.a);
        }
        if (a.g(FinancialChartCustomIndicatorArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(FinancialChartCustomIndicatorArgsDescriptionMetadata.a);
        SeriesDescriptionMetadata.d(a);
    };
    FinancialChartCustomIndicatorArgsDescriptionMetadata.c = function (a) {
        a.item("Series", "ExportedType:Series");
        a.item("Index", "Number:int");
    };
    FinancialChartCustomIndicatorArgsDescriptionMetadata.d = function (a) {
        FinancialChartCustomIndicatorArgsDescriptionMetadata.b(a);
        a.u("FinancialChartCustomIndicatorArgs", function () { return new FinancialChartCustomIndicatorArgsDescription(); });
        a.t("FinancialChartCustomIndicatorArgs", FinancialChartCustomIndicatorArgsDescriptionMetadata.a);
    };
    FinancialChartCustomIndicatorArgsDescriptionMetadata.$t = markType(FinancialChartCustomIndicatorArgsDescriptionMetadata, 'FinancialChartCustomIndicatorArgsDescriptionMetadata');
    FinancialChartCustomIndicatorArgsDescriptionMetadata.a = null;
    return FinancialChartCustomIndicatorArgsDescriptionMetadata;
}(Base));
export { FinancialChartCustomIndicatorArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/FinancialChartCustomIndicatorArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { FinancialChartCustomIndicatorArgsDescription } from "./FinancialChartCustomIndicatorArgsDescription";
/**
 * @hidden
 */
var FinancialChartCustomIndicatorArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FinancialChartCustomIndicatorArgsDescriptionMetadata, _super);
    function FinancialChartCustomIndicatorArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FinancialChartCustomIndicatorArgsDescriptionMetadata.b = function (a) {
        if (FinancialChartCustomIndicatorArgsDescriptionMetadata.a == null) {
            FinancialChartCustomIndicatorArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FinancialChartCustomIndicatorArgsDescriptionMetadata.c(FinancialChartCustomIndicatorArgsDescriptionMetadata.a);
        }
        if (a.j(FinancialChartCustomIndicatorArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(FinancialChartCustomIndicatorArgsDescriptionMetadata.a);
        SeriesDescriptionMetadata.d(a);
    };
    FinancialChartCustomIndicatorArgsDescriptionMetadata.c = function (a) {
        a.item("Series", "ExportedType:Series");
        a.item("Index", "Number:int");
    };
    FinancialChartCustomIndicatorArgsDescriptionMetadata.d = function (a) {
        FinancialChartCustomIndicatorArgsDescriptionMetadata.b(a);
        a.aa("FinancialChartCustomIndicatorArgs", function () { return new FinancialChartCustomIndicatorArgsDescription(); });
        a.z("FinancialChartCustomIndicatorArgs", FinancialChartCustomIndicatorArgsDescriptionMetadata.a);
    };
    FinancialChartCustomIndicatorArgsDescriptionMetadata.$t = markType(FinancialChartCustomIndicatorArgsDescriptionMetadata, 'FinancialChartCustomIndicatorArgsDescriptionMetadata');
    FinancialChartCustomIndicatorArgsDescriptionMetadata.a = null;
    return FinancialChartCustomIndicatorArgsDescriptionMetadata;
}(Base));
export { FinancialChartCustomIndicatorArgsDescriptionMetadata };
